##  Getting Started with the Integration
Integration with SAP Signavio, on a high level, involves the following steps:
  1. Set up a User Account in SAP Signavio
Set up a dedicated user account in SAP Signavio with appropriate read and write permissions. We recommend setting up a user account with an ‘API Edition’ license. For a detailed guide, see [Setup in SAP Signavio](https://help.sap.com/docs/leanix/ea/configuring-integration?locale=en-US&state=PRODUCTION&version=CLOUD#loio275c64207a441014b145d1ff0fd5f0f5__setup_in_sap_signavio).
  2. Provide Credentials in SAP LeanIX for Authentication
The credentials of that user account and the tenant ID are then entered in SAP LeanIX. They are necessary for authenticating the integration. Multiple instances of SAP Signavio can be integrated with SAP LeanIX, allowing you to integrate various tenants used by your organization for different regions or departments. For more details, see [Setup in SAP LeanIX](https://help.sap.com/docs/leanix/ea/configuring-integration?locale=en-US&state=PRODUCTION&version=CLOUD#loio275c64207a441014b145d1ff0fd5f0f5__setup_in_sap_leanix)[Setup in ](https://help.sap.com/docs/leanix/ea/configuring-integration?locale=en-US&state=PRODUCTION&version=CLOUD "Learn how to configure authentication for the SAP Signavio integration, including the necessary SAP Signavio user permissions required for proper setup and synchronization.").
  3. Map Processes from SAP Signavio to SAP LeanIX
Configure how processes from SAP Signavio should be mapped to SAP LeanIX. You have the option to map the process hierarchy either bottom-up, top-down, or simply synchronize based on a specified list of SAP Signavio directories. By default, processes are synced to the business context fact sheets in SAP LeanIX, and the direction is always from SAP Signavio to SAP LeanIX. If fact sheets with the same name already exist in SAP LeanIX, they are linked; otherwise, new fact sheets are created. For a detailed guide on mapping processes, see [Mapping SAP Signavio Processes to Fact Sheets](https://help.sap.com/docs/leanix/ea/mapping-sap-signavio-processes-to-fact-sheets?locale=en-US&state=PRODUCTION&version=CLOUD "Learn how to map and sync processes from SAP Signavio to SAP LeanIX. Configure synchronization modes, set process hierarchy, and manage process attributes with field and value mapping.").
  4. Map Process Attributes to Fact Sheet Attributes
Field mapping allows you to map process attributes from SAP Signavio to corresponding fields in SAP LeanIX fact sheets. During synchronization, these attributes are updated in the relevant fact sheet fields, and process diagrams from SAP Signavio are added to the fact sheet's resources tab. For a detailed guide on field mapping, see [Mapping Process Attributes to Fact Sheet Attributes](https://help.sap.com/docs/leanix/ea/mapping-sap-signavio-processes-to-fact-sheets?locale=en-US&state=PRODUCTION&version=CLOUD#loio275c6bbc7a441014a433b40fb48bd4d6__mapping_process_attributes_to_fact_sheet_attributes).
  5. Map Fact Sheets and Dictionary Items
Configure how applications, business capabilities, organizations, and other fact sheet types are mapped to corresponding SAP Signavio dictionary Items. This mapping is bidirectional, allowing you to choose the source and target systems and decide whether to sync from SAP LeanIX or SAP Signavio. We recommend using SAP LeanIX as the source of truth for applications, business capabilities, organizations, and data objects. Dictionary items so created in SAP Signavio can then be included in the process definitions by Signavio users. For a detailed guide, see [Mapping Fact Sheets and Dictionary Items](https://help.sap.com/docs/leanix/ea/mapping-fact-sheets-and-dictionary-items?locale=en-US&state=PRODUCTION&version=CLOUD#loio275c67fd7a441014b2ec90b746a268b3__mapping_fact_sheets_and_dictionary_items-d26e44).
  6. Map Fact Sheet Attributes and Dictionary Item Fields
Through field mapping, you map how fact sheet attributes and dictionary item fields should be synced between the two systems. For a detailed guide, see [Mapping Fact Sheet Attributes and Dictionary Item Fields](https://help.sap.com/docs/leanix/ea/mapping-fact-sheets-and-dictionary-items?locale=en-US&state=PRODUCTION&version=CLOUD#loio275c67fd7a441014b2ec90b746a268b3__mapping_fact_sheet_attributes_and_dictionary_item_fields).
  7. Run Synchronization
After configuring the integration, run the synchronization to create and update fact sheets, dictionary items, and their associated relations. Changes in one system are automatically reflected in the other based on your source and target system settings. You can also set up a synchronization interval to automatically run the sync runs.
